@@ -32,3 +32,11 @@ Score::~Score()
         settings.setValue("draw", score_[i][2]);
     }
 }
+
+void Score::reset()
+{
+    for (unsigned i = 0; i < NUM_AI_LEVELS; ++i)
+    {
+        score_[i][0] = score_[i][1] = score_[i][2] = 0;
+    }
+}
